yt.utilities.particle\_generator module
=======================================

.. automodule:: yt.utilities.particle_generator
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
